import setuptools

setuptools.setup(
    name = "jcproj",
    version = "0.0.2",
    author = "Li Jicher",
    author_email='lijichen8c@163.com',
    description = "this is a mess package to solve something",
    packages = setuptools.find_packages(),
)